@@ -65,11 +65,9 @@ sub requires {
 
     return {
 	'Carp'			=> 0,
-	'Compress::Zlib'	=> 0,
 	'Data::Dumper'		=> 0,
 	'Exporter'		=> 0,
 	'Getopt::Long'		=> 0,
-	'HTML::Parser'		=> 0,
 	'HTTP::Response'	=> 0,
 	'HTTP::Status'		=> 6.03,	# For the teapot status
 	'IO::File'		=> 0,
